# HTTP response

Images from http response serves, e.g. `EigerDectris`

The HTTP response image source frame contains the following fields:

- URL: selects the url or its shortcut to the detector HTTP server.
  e.g. `http://haso228eiger/monitor/api/1.5.0/images/monitor` or `haso228eiger/1.5.0`.
  The possible URLs can be preselected in the configuration dialog.
- Status: shows the connection status. It also displays a port of ZMQ security stream if it is enabled.
- Start/Stop button to launch or interrupt image querying